/**
 * JASMINe
 * Copyright (C) 2005-2007 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Help.java 38 2007-12-12 13:03:04Z tokmensa $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.mbeancmd.commands;

import org.ow2.jasmine.monitoring.mbeancmd.Command;
import org.ow2.jasmine.monitoring.mbeancmd.CommandDispatcher;

/**
 * Command that displays application help.
 */
public class Help implements Command {
    /**
     * Implementation of inherited method.
     *
     * @see org.ow2.jasmine.monitoring.mbeancmd.Command#setArgs(java.lang.String, java.lang.String[])
     */
    public void setArgs(final String cmd, final String[] args) {
        this.name = cmd.toLowerCase();
        this.arguments = args;
    }

    /**
     * Implementation of inherited method.
     *
     * @see org.ow2.jasmine.monitoring.mbeancmd.Command#exec()
     */
    public void exec() {
        if (arguments == null) {
            System.out.println("\nAvailable commands:\n");
            String[] cmds = CommandDispatcher.getAvailableCommands();
            for (int i = 0; i < cmds.length; i++) {
                Command cmd = CommandDispatcher.getCommand(cmds[i]);
                System.out.println(cmds[i] + " - " + cmd.summary());
            }
            System.out.println();
            this.help();
        } else {
            for (int i = 0; i < arguments.length; i++) {
                Command cmd = CommandDispatcher.getCommand(arguments[i]);
                if (cmd == null) {
                    System.out.println("Unknown command: " + arguments[i]);
                } else {
                    cmd.help();
                }
                System.out.println();
            }
        }
        System.exit(0);
    }

    /**
     * Implementation of inherited method.
     *
     * @see org.ow2.jasmine.monitoring.mbeancmd.Command#summary()
     */
    public String summary() {
        return "provides help on available commands";
    }

    /**
     * Implementation of inherited method.
     *
     * @see org.ow2.jasmine.monitoring.mbeancmd.Command#help()
     */
    public void help() {
        System.out.println(
                  "Usage: help [ command, ... ]\n"
                + "\t- without arguments, lists a summary of the available commands\n"
                + "\t- with arguments, prints full help for each passed command\n"
        );
    }

    /**
     * Implementation of inherited method.
     *
     * @see org.ow2.jasmine.monitoring.mbeancmd.Command#getName()
     */
    public String getName() {
        return name;
    }

    /**
     * Name of the command.
     */
    private String name = null;

    /**
     * Command arguments.
     */
    private String[] arguments = null;
}
