/**
 * JASMINe
 * Copyright (C) 2005-2007 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: SamplerFactory.java 41 2007-12-13 14:17:00Z tokmensa $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.mbeancmd.sampling;

/**
 * Sampler factory.
 */
public class SamplerFactory {
    /**
     * Dummy constructor to avoid the class from being used
     * in any other way than calling the CommandDispatcher.newSampler method.
     */
    protected SamplerFactory() {
        // Nothing
    }

    /**
     * Creates a sampler of a given type. Calls
     * {@link SamplerFactory#newSampler(String, String)}
     * with urlString set to null.
     *
     * @param type  Sampler type.
     *
     * @return  Created sampler, null if type doesn't match  any sampler.
     */
    public static Sampler newSampler(final String type) {
        return newSampler(type, null);
    }

    /**
     * Creates a sampler of a given type and a given JMX URL.
     *
     * @param type       Sampler type.
     * @param urlString  JMX URL.
     *
     * @return  Created sampler, null if type doesn't match  any sampler.
     */
    public static Sampler newSampler(final String type, final String urlString) {
        Sampler sampler = null;

        if ("web".equals(type)) {
            sampler = new WebSampler(urlString);
        }
        if ("tx".equals(type)) {
            sampler = new TxSampler(urlString);
        }
        if ("cpusun".equals(type)) {
            sampler = new CpuSunSampler(urlString);
        }
        if ("server".equals(type)) {
            sampler = new ServerSampler(urlString);
        }
        if ("datasource".equals(type)) {
            sampler = new DSSampler(urlString);
        }
        if ("jcacf".equals(type)) {
            sampler = new JCACFSampler(urlString);
        }
        if ("servlet".equals(type)) {
            sampler = new ServletSampler(urlString);
        }
        if ("stateless".equals(type)) {
            sampler = new SLBSampler(urlString);
        }
        if ("stateful".equals(type)) {
            sampler = new SFBSampler(urlString);
        }
        if ("entity".equals(type)) {
            sampler = new EntitySampler(urlString);
        }

        return sampler;
    }
}
